# Безопасность

## Встроенные примитивы

- Охранник JWT
- Менеджер ключей API
- Профили CORS
- CSRF-защитник
- Секретный менеджер
- Регистратор аудита

## Лучшие практики

- Вращайте секреты и ключи
- Используйте строгий CORS в производстве.
- Принудительная проверка авторизации для конфиденциальных маршрутов.
- Регистрировать события безопасности с идентификаторами корреляции.